@@ -8,7 +8,7 @@
 
 use super::{
     chunk::{Chunk, ChunkId},
-    ChunkStore, Result as ChunkStoreResult, Subdir, UsedSpace,
+    ChunkStore, Result as ChunkStoreResult, Subdir,
 };
 use crate::{to_db_key::ToDbKey, Error, Result};
 use rand::{distributions::Standard, rngs::ThreadRng, Rng};
@@ -94,8 +94,7 @@ async fn successful_put() -> Result<()> {
     let chunks = Chunks::gen(&mut rng)?;
 
     let root = temp_dir()?;
-    let used_space = UsedSpace::new(u64::MAX);
-    let mut chunk_store = ChunkStore::<Data>::new(root.path(), used_space.clone()).await?;
+    let mut chunk_store = ChunkStore::<Data>::new(root.path(), u64::MAX).await?;
 
     for (index, (data, size)) in chunks.data_and_sizes.iter().enumerate().rev() {
         let the_data = &Data {
@@ -130,8 +129,7 @@ async fn failed_put_when_not_enough_space() -> Result<()> {
     let mut rng = new_rng();
     let root = temp_dir()?;
     let capacity = 32;
-    let used_space = UsedSpace::new(capacity);
-    let mut chunk_store = ChunkStore::new(root.path(), used_space.clone()).await?;
+    let mut chunk_store = ChunkStore::new(root.path(), capacity).await?;
 
     let data = Data {
         id: Id(rng.gen()),
@@ -155,8 +153,7 @@ async fn delete() -> Result<()> {
     let chunks = Chunks::gen(&mut rng)?;
 
     let root = temp_dir()?;
-    let used_space = UsedSpace::new(u64::MAX);
-    let mut chunk_store = ChunkStore::new(root.path(), used_space.clone()).await?;
+    let mut chunk_store = ChunkStore::new(root.path(), u64::MAX).await?;
 
     for (index, (data, size)) in chunks.data_and_sizes.iter().enumerate() {
         let the_data = &Data {
@@ -180,8 +177,7 @@ async fn put_and_get_value_should_be_same() -> Result<()> {
     let chunks = Chunks::gen(&mut rng)?;
 
     let root = temp_dir()?;
-    let used_space = UsedSpace::new(u64::MAX);
-    let mut chunk_store = ChunkStore::new(root.path(), used_space.clone()).await?;
+    let mut chunk_store = ChunkStore::new(root.path(), u64::MAX).await?;
 
     for (index, (data, _)) in chunks.data_and_sizes.iter().enumerate() {
         chunk_store
@@ -206,8 +202,7 @@ async fn overwrite_value() -> Result<()> {
     let chunks = Chunks::gen(&mut rng)?;
 
     let root = temp_dir()?;
-    let used_space = UsedSpace::new(u64::MAX);
-    let mut chunk_store = ChunkStore::new(root.path(), used_space.clone()).await?;
+    let mut chunk_store = ChunkStore::new(root.path(), u64::MAX).await?;
 
     for (data, size) in chunks.data_and_sizes {
         chunk_store
@@ -227,8 +222,7 @@ async fn overwrite_value() -> Result<()> {
 #[tokio::test]
 async fn get_fails_when_key_does_not_exist() -> Result<()> {
     let root = temp_dir()?;
-    let used_space = UsedSpace::new(u64::MAX);
-    let chunk_store: ChunkStore<Data> = ChunkStore::new(root.path(), used_space.clone()).await?;
+    let chunk_store: ChunkStore<Data> = ChunkStore::new(root.path(), u64::MAX).await?;
 
     let id = Id(new_rng().gen());
     match chunk_store.get(&id) {
@@ -245,8 +239,7 @@ async fn keys() -> Result<()> {
     let chunks = Chunks::gen(&mut rng)?;
 
     let root = temp_dir()?;
-    let used_space = UsedSpace::new(u64::MAX);
-    let mut chunk_store = ChunkStore::new(root.path(), used_space.clone()).await?;
+    let mut chunk_store = ChunkStore::new(root.path(), u64::MAX).await?;
 
     for (index, (data, _)) in chunks.data_and_sizes.iter().enumerate() {
         let id = Id(index as u64);
