@@ -1,4 +1,4 @@
-use std::collections::{BTreeSet, HashMap, HashSet};
+use std::collections::{BTreeSet, HashMap};
 
 // Copyright 2021 MaidSafe.net limited.
 //
@@ -9,7 +9,6 @@ use std::collections::{BTreeSet, HashMap, HashSet};
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use itertools::Itertools;
-use log::debug;
 use sn_data_types::BlobAddress;
 use sn_messaging::{client::BlobWrite, EndUser, MessageId};
 use sn_routing::XorName;
@@ -56,13 +55,13 @@ impl AdultLiveness {
         msg_id: MessageId,
         origin: Option<EndUser>,
         blob_write: BlobWrite,
-        targets: BTreeSet<XorName>,
+        targets: &BTreeSet<XorName>,
     ) -> bool {
         let new_operation = if let Entry::Vacant(entry) = self.ops.entry(msg_id) {
             let _ = entry.insert(Operation::Write {
                 blob_write: Box::new(blob_write),
-                origin,
                 targets: targets.clone(),
+                origin,
             });
             true
         } else {
@@ -139,8 +138,6 @@ impl AdultLiveness {
         if complete {
             let _ = self.ops.remove(&msg_id);
         }
-        debug!("Pending op. count: {:?}", &self.pending_ops);
-        debug!("Ongoing ops: {:?}", &self.ops);
     }
 
     pub fn record_adult_write_liveness(
@@ -184,17 +181,23 @@ impl AdultLiveness {
     }
 
     pub fn recompute_closest_adults(&mut self) {
-        let adults = self.closest_adults.keys().cloned().collect::<HashSet<_>>();
-        for adult in &adults {
-            let closest_adults = adults
-                .iter()
-                .filter(|name| name != &adult)
-                .sorted_by(|lhs, rhs| adult.cmp_distance(lhs, rhs))
-                .take(NEIGHBOUR_COUNT)
-                .cloned()
-                .collect::<Vec<_>>();
-            let _ = self.closest_adults.insert(*adult, closest_adults);
-        }
+        let closest_adults_collection = self
+            .closest_adults
+            .iter()
+            .map(|(key, value)| {
+                let closest_adults = value
+                    .iter()
+                    .filter(|name| key != *name)
+                    .sorted_by(|lhs, rhs| key.cmp_distance(lhs, rhs))
+                    .take(NEIGHBOUR_COUNT)
+                    .copied()
+                    .collect::<Vec<_>>();
+
+                (key.to_owned(), closest_adults)
+            })
+            .collect::<Vec<(XorName, Vec<XorName>)>>();
+
+        self.closest_adults.extend(closest_adults_collection);
     }
 
     pub fn find_unresponsive_adults(&self) -> Vec<(XorName, usize)> {
@@ -202,13 +205,14 @@ impl AdultLiveness {
         for (adult, neighbours) in &self.closest_adults {
             if let Some(max_pending_by_neighbours) = neighbours
                 .iter()
-                .map(|neighbour| self.pending_ops.get(neighbour).cloned().unwrap_or(0))
+                .map(|neighbour| self.pending_ops.get(neighbour).unwrap_or(&0))
                 .max()
             {
                 let adult_pending_ops = *self.pending_ops.get(adult).unwrap_or(&0);
                 if adult_pending_ops > MIN_PENDING_OPS
+                    && max_pending_by_neighbours > &MIN_PENDING_OPS
                     && adult_pending_ops as f64 * PENDING_OP_TOLERANCE_RATIO
-                        > max_pending_by_neighbours as f64
+                        > *max_pending_by_neighbours as f64
                 {
                     log::info!(
                         "Pending ops for {}: {} Neighbour max: {}",
