@@ -6,19 +6,17 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
+use super::{build_client_error_response, build_client_query_response};
 use crate::{
-    chunk_store::RegisterChunkStore,
-    error::convert_to_error_message,
-    node_ops::{NodeDuty, OutgoingMsg},
-    Error, Result,
+    chunk_store::RegisterChunkStore, error::convert_to_error_message, node_ops::NodeDuty, Error,
+    Result,
 };
 use log::info;
 use sn_data_types::register::{Action, Address, Entry, Register, RegisterOp, User};
 use sn_messaging::{
-    client::{CmdError, Message, QueryResponse, RegisterRead, RegisterWrite},
-    Aggregation, DstLocation, EndUser, MessageId,
+    client::{CmdError, QueryResponse, RegisterRead, RegisterWrite},
+    EndUser, MessageId,
 };
-
 use std::{
     fmt::{self, Display, Formatter},
     path::Path,
@@ -90,19 +88,14 @@ impl RegisterStorage {
     async fn get(&self, address: Address, msg_id: MessageId, origin: EndUser) -> Result<NodeDuty> {
         let result = match self.get_chunk(address, Action::Read, origin) {
             Ok(res) => Ok(res),
-            Err(error) => Err(convert_to_error_message(error)?),
+            Err(error) => Err(convert_to_error_message(error)),
         };
 
-        Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::QueryResponse {
-                response: QueryResponse::GetRegister(result),
-                id: MessageId::in_response_to(&msg_id),
-                correlation_id: msg_id,
-            },
-            section_source: false, // strictly this is not correct, but we don't expect responses to a response..
-            dst: DstLocation::EndUser(origin),
-            aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-        }))
+        Ok(NodeDuty::Send(build_client_query_response(
+            QueryResponse::GetRegister(result),
+            msg_id,
+            origin,
+        )))
     }
 
     fn get_chunk(&self, address: Address, action: Action, origin: EndUser) -> Result<Register> {
@@ -151,19 +144,14 @@ impl RegisterStorage {
             .and_then(|register| register.read(Some(*origin.id())).map_err(Error::from))
         {
             Ok(res) => Ok(res),
-            Err(error) => Err(convert_to_error_message(error)?),
+            Err(error) => Err(convert_to_error_message(error)),
         };
 
-        Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::QueryResponse {
-                response: QueryResponse::ReadRegister(result),
-                id: MessageId::in_response_to(&msg_id),
-                correlation_id: msg_id,
-            },
-            section_source: false, // strictly this is not correct, but we don't expect responses to a response..
-            dst: DstLocation::EndUser(origin),
-            aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-        }))
+        Ok(NodeDuty::Send(build_client_query_response(
+            QueryResponse::ReadRegister(result),
+            msg_id,
+            origin,
+        )))
     }
 
     async fn get_owner(
@@ -174,19 +162,14 @@ impl RegisterStorage {
     ) -> Result<NodeDuty> {
         let result = match self.get_chunk(address, Action::Read, origin) {
             Ok(res) => Ok(res.owner()),
-            Err(error) => Err(convert_to_error_message(error)?),
+            Err(error) => Err(convert_to_error_message(error)),
         };
 
-        Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::QueryResponse {
-                response: QueryResponse::GetRegisterOwner(result),
-                id: MessageId::in_response_to(&msg_id),
-                correlation_id: msg_id,
-            },
-            section_source: false, // strictly this is not correct, but we don't expect responses to a response..
-            dst: DstLocation::EndUser(origin),
-            aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-        }))
+        Ok(NodeDuty::Send(build_client_query_response(
+            QueryResponse::GetRegisterOwner(result),
+            msg_id,
+            origin,
+        )))
     }
 
     async fn get_user_permissions(
@@ -204,19 +187,14 @@ impl RegisterStorage {
                     .map_err(Error::from)
             }) {
             Ok(res) => Ok(res),
-            Err(error) => Err(convert_to_error_message(error)?),
+            Err(error) => Err(convert_to_error_message(error)),
         };
 
-        Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::QueryResponse {
-                response: QueryResponse::GetRegisterUserPermissions(result),
-                id: MessageId::in_response_to(&msg_id),
-                correlation_id: msg_id,
-            },
-            section_source: false, // strictly this is not correct, but we don't expect responses to a response..
-            dst: DstLocation::EndUser(origin),
-            aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-        }))
+        Ok(NodeDuty::Send(build_client_query_response(
+            QueryResponse::GetRegisterUserPermissions(result),
+            msg_id,
+            origin,
+        )))
     }
 
     async fn get_policy(
@@ -234,19 +212,14 @@ impl RegisterStorage {
                     .map_err(Error::from)
             }) {
             Ok(res) => Ok(res),
-            Err(error) => Err(convert_to_error_message(error)?),
+            Err(error) => Err(convert_to_error_message(error)),
         };
 
-        Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::QueryResponse {
-                response: QueryResponse::GetRegisterPolicy(result),
-                id: MessageId::in_response_to(&msg_id),
-                correlation_id: msg_id,
-            },
-            section_source: false, // strictly this is not correct, but we don't expect responses to a response..
-            dst: DstLocation::EndUser(origin),
-            aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-        }))
+        Ok(NodeDuty::Send(build_client_query_response(
+            QueryResponse::GetRegisterPolicy(result),
+            msg_id,
+            origin,
+        )))
     }
 
     async fn edit(
@@ -300,19 +273,15 @@ impl RegisterStorage {
             Ok(_) => return Ok(NodeDuty::NoOp),
             Err(error) => {
                 info!("Error on writing Register! {:?}", error);
-                convert_to_error_message(error)?
+                convert_to_error_message(error)
             }
         };
-        Ok(NodeDuty::Send(OutgoingMsg {
-            msg: Message::CmdError {
-                id: MessageId::in_response_to(&msg_id),
-                error: CmdError::Data(error),
-                correlation_id: msg_id,
-            },
-            section_source: false, // strictly this is not correct, but we don't expect responses to an error..
-            dst: DstLocation::Section(origin.name()),
-            aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-        }))
+
+        Ok(NodeDuty::Send(build_client_error_response(
+            CmdError::Data(error),
+            msg_id,
+            origin,
+        )))
     }
 }
 
